package com.ylx.massage.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;

import java.io.Serializable;

/**
 * <p>
 * 轮播图
 * </p>
 *
 * @author YJR
 * @since 2023-11-24
 */
@Getter
@Setter
@Accessors(chain = true)
@TableName("t_lbt")
@ApiModel(value = "TLbt", description = "轮播图")
public class TLbt implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @TableId("c_id")
    @ApiModelProperty("cId")
    private String cId;

    /**
     * 图片地址
     */
    @TableField("c_img_url")
    @ApiModelProperty("图片地址")
    private String cImgUrl;

    /**
     * 描述
     */
    @TableField("c_describe")
    @ApiModelProperty("描述")
    private String cDescribe;

    /**
     * 文本内容
     */
    @TableField("c_content")
    @ApiModelProperty("文本内容")
    private String cContent;

    @ApiModelProperty("是否删除0否1是")
    @TableLogic
    private Integer isDelete;

    /**
     * 序号
     */
    @TableField("c_sort")
    @ApiModelProperty("序号")
    private Integer cSort;

    public String getcId() {
        return cId;
    }

    public void setcId(String cId) {
        this.cId = cId;
    }

    public String getcImgUrl() {
        return cImgUrl;
    }

    public void setcImgUrl(String cImgUrl) {
        this.cImgUrl = cImgUrl;
    }


    public String getcDescribe() {
        return cDescribe;
    }

    public void setcDescribe(String cDescribe) {
        this.cDescribe = cDescribe;
    }

    public String getcContent() {
        return cContent;
    }

    public void setcContent(String cContent) {
        this.cContent = cContent;
    }

    public Integer getcSort() {
        return cSort;
    }

    public void setcSort(Integer cSort) {
        this.cSort = cSort;
    }
}
